@@ -72,6 +72,11 @@ class SubRipShifter(object):
         Change file encoding. Useful for players accepting only latin1 subtitles.
         List of supported encodings: http://docs.python.org/library/codecs.html#standard-encodings
     """)
+    BREAK_EPILOG = dedent("""\
+        Break lines longer than defined length
+    """)
+    LENGTH_HELP = "Maximum number of characters per line"
+
     def __init__(self):
         self.output_file_path = None
 
@@ -90,13 +95,17 @@ class SubRipShifter(object):
         shift_parser.set_defaults(action=self.shift)
 
         rate_parser = subparsers.add_parser('rate', help="Convert subtitles from a frame rate to another", epilog=self.RATE_EPILOG, formatter_class=argparse.RawTextHelpFormatter)
-        rate_parser.add_argument(underline('initial'), action='store', type=float, help=self.FRAME_RATE_HELP)
-        rate_parser.add_argument(underline('final'), action='store', type=float, help=self.FRAME_RATE_HELP)
+        rate_parser.add_argument('initial', action='store', type=float, help=self.FRAME_RATE_HELP)
+        rate_parser.add_argument('final', action='store', type=float, help=self.FRAME_RATE_HELP)
         rate_parser.set_defaults(action=self.rate)
 
         split_parser = subparsers.add_parser('split', help="Split a file in multiple parts", epilog=self.SPLIT_EPILOG, formatter_class=argparse.RawTextHelpFormatter)
-        split_parser.add_argument(underline('limits'), action='store', nargs='+', type=self.parse_time, help=self.LIMITS_HELP)
+        split_parser.add_argument('limits', action='store', nargs='+', type=self.parse_time, help=self.LIMITS_HELP)
         split_parser.set_defaults(action=self.split)
+
+        break_parser = subparsers.add_parser('break', help="Break long lines", epilog=self.BREAK_EPILOG, formatter_class=argparse.RawTextHelpFormatter)
+        break_parser.add_argument('length', action='store', type=int, help=self.LENGTH_HELP)
+        break_parser.set_defaults(action=self.break_lines)
         
         parser.add_argument('file', action='store')
 
@@ -151,6 +160,13 @@ class SubRipShifter(object):
         self.output_file_path = self.arguments.file
         self.arguments.file = backup_file
 
+    def break_lines(self):
+        split_re = re.compile(r'(.{,%i})(?:\s+|$)' % self.arguments.length)
+        for item in self.input_file:
+            item.text = u'\n'.join(split_re.split(item.text)[1::2])
+        self.input_file.write_into(self.output_file)
+        self.output_file.close()
+
     @property
     def output_encoding(self):
         return self.arguments.output_encoding or self.input_file.encoding
